|
From: <sv...@va...> - 2009-08-16 23:01:35
|
Author: sewardj
Date: 2009-08-16 23:52:29 +0100 (Sun, 16 Aug 2009)
New Revision: 10831
Log:
Increase the maximum size of the conflict cache even more, to 30
million.
Modified:
trunk/helgrind/hg_main.c
trunk/helgrind/libhb_core.c
Modified: trunk/helgrind/hg_main.c
===================================================================
--- trunk/helgrind/libhb_core.c 2009-08-16 22:49:53 UTC (rev 10830)
+++ trunk/helgrind/libhb_core.c 2009-08-16 22:52:29 UTC (rev 10831)
@@ -3797,7 +3797,7 @@
/* Check for sane command line params. Limit values must match
those in hg_process_cmd_line_option. */
tl_assert( HG_(clo_conflict_cache_size) >= 10*1000 );
- tl_assert( HG_(clo_conflict_cache_size) <= 20*1000*1000 );
+ tl_assert( HG_(clo_conflict_cache_size) <= 30*1000*1000 );
/* Check our counting is sane (expensive) */
if (CHECK_CEM)
|
--- trunk/helgrind/hg_main.c 2009-08-16 22:49:53 UTC (rev 10830)
+++ trunk/helgrind/hg_main.c 2009-08-16 22:52:29 UTC (rev 10831)
@@ -4397,10 +4397,10 @@
else if VG_XACT_CLO(arg, "--history-level=full",
HG_(clo_history_level), 2);
/* If you change the 10k/20mill limits, remember to also change
them in assertions at the top of event_map_maybe_GC. */
else if VG_BINT_CLO(arg, "--conflict-cache-size",
- HG_(clo_conflict_cache_size), 10*1000, 20*1000*1000) {}
+ HG_(clo_conflict_cache_size), 10*1000, 30*1000*1000) {}
/* "stuvwx" --> stuvwx (binary) */
else if VG_STR_CLO(arg, "--hg-sanity-flags", tmp_str) {
Modified: trunk/helgrind/libhb_core.c
@@ -4397,10 +4397,10 @@
else if VG_XACT_CLO(arg, "--history-level=full",
HG_(clo_history_level), 2);
- /* If you change the 10k/20mill limits, remember to also change
+ /* If you change the 10k/30mill limits, remember to also change
them in assertions at the top of event_map_maybe_GC. */
else if VG_BINT_CLO(arg, "--conflict-cache-size",
===================================================================